@@ -52,25 +52,29 @@ using namespace KContacts;
 
 static void addEscapes(QByteArray &str, bool excludeEscapteComma)
 {
-    str.replace('\\', (char *)"\\\\");
+    str.replace('\\', "\\\\");
     if (!excludeEscapteComma) {
-        str.replace(',', (char *)"\\,");
+        str.replace(',', "\\,");
     }
-    str.replace('\r', (char *)"\\r");
-    str.replace('\n', (char *)"\\n");
+    str.replace('\r', "\\r");
+    str.replace('\n', "\\n");
 }
 
 static void removeEscapes(QByteArray &str)
 {
-    str.replace((char *)"\\n", "\n");
-    str.replace((char *)"\\N", "\n");
-    str.replace((char *)"\\r", "\r");
-    str.replace((char *)"\\,", ",");
-    str.replace((char *)"\\\\", "\\");
+    // It's more likely that no escape is present, so add fast path
+    if (!str.contains('\\')) {
+        return;
+    }
+    str.replace("\\n", "\n");
+    str.replace("\\N", "\n");
+    str.replace("\\r", "\r");
+    str.replace("\\,", ",");
+    str.replace("\\\\", "\\");
 }
 
 VCardParser::VCardParser()
-    : d(Q_NULLPTR)
+    : d(nullptr)
 {
 }
 
@@ -88,7 +92,7 @@ VCard::List VCardParser::parseVCards(const QByteArray &text)
 
     bool inVCard = false;
     QList<QByteArray>::Iterator it(lines.begin());
-    QList<QByteArray>::Iterator linesEnd(lines.end());
+    const QList<QByteArray>::Iterator linesEnd(lines.end());
 
     StringCache cache;
 
@@ -119,10 +123,10 @@ VCard::List VCardParser::parseVCards(const QByteArray &text)
                 for (int i = 0; i < currentLineLength; ++i) {
                     char character = currentLine.at(i);
                     if (keyFound) {
-                        QList<QByteArray> tmpParams = currentLine.right(currentLineLength - i).split(';');
+                        const QList<QByteArray> tmpParams = currentLine.right(currentLineLength - i).split(';');
                         QByteArray tmpParameter;
                         bool valueAdded = false;
-                        Q_FOREACH (const QByteArray &parameter, tmpParams) {
+                        for (const QByteArray &parameter : tmpParams) {
                             if (parameter.contains('=')) {
                                 if (tmpParameter.isEmpty()) {
                                     tmpParameter = parameter;
@@ -311,7 +315,7 @@ QByteArray VCardParser::createVCards(const VCard::List &list)
     text.reserve(list.size() * 300);   // reserve memory to be more efficient
 
     // iterate over the cards
-    VCard::List::ConstIterator listEnd(list.end());
+    const VCard::List::ConstIterator listEnd(list.end());
     for (cardIt = list.begin(); cardIt != listEnd; ++cardIt) {
         text.append("BEGIN:VCARD\r\n");
 
